@@ -10,7 +10,7 @@
 #
 # @section dependencies Dependencies
 #
-# this library requires a physical connection to a Notecard over I2C or
+# This library requires a physical connection to a Notecard over I2C or
 # Serial to be functional.
 # @section author Author
 #
@@ -35,6 +35,7 @@ import json
 import time
 
 use_periphery = False
+use_micropython = False
 use_serial_lock = False
 if sys.implementation.name == 'cpython':
     if sys.platform == "linux" or sys.platform == "linux2":
@@ -43,6 +44,8 @@ if sys.implementation.name == 'cpython':
 
         use_serial_lock = True
         from filelock import Timeout, FileLock
+elif sys.implementation.name == 'micropython':
+    use_micropython = True
 
 NOTECARD_I2C_ADDRESS = 0x17
 
@@ -80,7 +83,7 @@ def serialReset(port):
         nonControlCharFound = False
         while True:
             data = serialReadByte(port)
-            if data is None:
+            if (data is None) or (data == b''):
                 break
             somethingFound = True
             if data[0] >= 0x20:
@@ -92,7 +95,7 @@ def serialReset(port):
 
 
 def serialTransaction(port, req, debug):
-    """Perform a single write to a read from a Notecard."""
+    """Perform a single write to and read from a Notecard."""
     req_json = json.dumps(req)
     if debug:
         print(req_json)
@@ -131,6 +134,29 @@ def serialTransaction(port, req, debug):
     return rsp
 
 
+def serialCommand(port, req, debug):
+    """Perform a single write to and read from a Notecard."""
+    req_json = json.dumps(req)
+    if debug:
+        print(req_json)
+    req_json += "\n"
+
+    seg_off = 0
+    seg_left = len(req_json)
+    while True:
+        seg_len = seg_left
+        if seg_len > CARD_REQUEST_SEGMENT_MAX_LEN:
+            seg_len = CARD_REQUEST_SEGMENT_MAX_LEN
+
+        port.write(req_json[seg_off:seg_off + seg_len]
+                   .encode('utf-8'))
+        seg_off += seg_len
+        seg_left -= seg_len
+        if seg_left == 0:
+            break
+        time.sleep(CARD_REQUEST_SEGMENT_DELAY_MS / 1000)
+
+
 class Notecard:
     """Base Notecard class.
 
@@ -146,17 +172,24 @@ class Notecard:
 class OpenSerial(Notecard):
     """Notecard class for Serial communication."""
 
-    def Request(self, req):
-        """Call the Transaction method and discard the result."""
-        self.Transaction(req)
-        return True
+    def Command(self, req):
+        """Perform a Notecard command and exit with no response."""
+        if 'cmd' not in req:
+            raise Exception("Please use 'cmd' instead of 'req'")
 
-    def RequestResponse(self, req):
-        """Call the Transaction method and return the result."""
-        return self.Transaction(req)
+        if use_serial_lock:
+            try:
+                self.lock.acquire(timeout=5)
+                serialCommand(self.uart, req, self._debug)
+            except Timeout:
+                raise Exception("Notecard in use")
+            finally:
+                self.lock.release()
+        else:
+            serialCommand(self.uart, req, self._debug)
 
     def Transaction(self, req):
-        """Perform a Notecard transaction discard the result."""
+        """Perform a Notecard transaction and return the result."""
         if use_serial_lock:
             try:
                 self.lock.acquire(timeout=5)
@@ -194,8 +227,24 @@ class OpenSerial(Notecard):
 class OpenI2C(Notecard):
     """Notecard class for I2C communication."""
 
+    def Command(self, req):
+        """Perform a Notecard command and exit with no response."""
+        if 'cmd' not in req:
+            raise Exception("Please use 'cmd' instead of 'req'")
+
+        if use_serial_lock:
+            try:
+                self.lock.acquire(timeout=5)
+                serialCommand(self.uart, req, self._debug)
+            except Timeout:
+                raise Exception("Notecard in use")
+            finally:
+                self.lock.release()
+        else:
+            serialCommand(self.uart, req, self._debug)
+
     def Transaction(self, req):
-        """Perform a Notecard transaction discard the result."""
+        """Perform a Notecard transaction and return the result."""
         req_json = json.dumps(req)
         if self._debug:
             print(req_json)
@@ -222,6 +271,9 @@ class OpenI2C(Notecard):
                 if use_periphery:
                     msgs = [I2C.Message(reg + write_data)]
                     self.i2c.transfer(self.addr, msgs)
+                elif use_micropython:
+                    self.i2c.writeto(self.addr, reg, False)
+                    self.i2c.writeto(self.addr, write_data, True)
                 else:
                     self.i2c.writeto(self.addr, reg + write_data)
                 chunk_offset += chunk_len
@@ -246,6 +298,9 @@ class OpenI2C(Notecard):
                     msgs = [I2C.Message(reg), I2C.Message(buf, read=True)]
                     self.i2c.transfer(self.addr, msgs)
                     buf = msgs[1].data
+                elif use_micropython:
+                    self.i2c.writeto(self.addr, reg, False)
+                    self.i2c.readfrom_into(self.addr, buf)
                 else:
                     self.i2c.writeto_then_readfrom(self.addr, reg, buf)
                 available = buf[0]
@@ -293,6 +348,9 @@ class OpenI2C(Notecard):
                     msgs = [I2C.Message(reg), I2C.Message(buf, read=True)]
                     self.i2c.transfer(self.addr, msgs)
                     buf = msgs[1].data
+                elif use_micropython:
+                    self.i2c.writeto(self.addr, reg, False)
+                    self.i2c.readfrom_into(self.addr, buf)
                 else:
                     self.i2c.writeto_then_readfrom(self.addr, reg, buf)
                 available = buf[0]
@@ -306,13 +364,13 @@ class OpenI2C(Notecard):
 
     def lock(self):
         """Lock the I2C port so the host can interact with the Notecard."""
-        if not use_periphery:
+        if not use_periphery and not use_micropython:
             return self.i2c.try_lock()
         return True
 
     def unlock(self):
         """Unlock the I2C port."""
-        if not use_periphery:
+        if not use_periphery and not use_micropython:
             return self.i2c.unlock()
         return True
 
